==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/components/keyrings/common/data_file/reader.h <==
/* Copyright (c) 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef READER_INCLUDED
#define READER_INCLUDED

#include <string>

namespace keyring_common {

namespace data_file {
/* RAII class to read a file */
class File_reader final {
 public:
  explicit File_reader(const std::string &file, bool read_only,
                       std::string &data);

  /* Destructor */
  ~File_reader() { valid_ = false; }

  /* Get data size */
  size_t size() const { return size_; }

  /* Validity of reader */
  bool valid() const { return valid_; }

 private:
  bool read_data_from_file(const std::string &file, std::string &data);

  /** Validity of the reader */
  bool valid_;
  /** File size */
  size_t size_;
};

}  // namespace data_file

}  // namespace keyring_common

#endif  // !READER_INCLUDED

==> mysql-9.5.0.tar.gz: mysql-9.5.0/components/keyrings/common/data_file/reader.h <==
/* Copyright (c) 2021, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef READER_INCLUDED
#define READER_INCLUDED

#include <string>

namespace keyring_common::data_file {

/* RAII class to read a file */
class File_reader final {
 public:
  explicit File_reader(const std::string &file, bool read_only,
                       std::string &data);

  /* Destructor */
  ~File_reader() { valid_ = false; }

  /* Get data size */
  size_t size() const { return size_; }

  /* Validity of reader */
  bool valid() const { return valid_; }

 private:
  bool read_data_from_file(const std::string &file, std::string &data);

  /** Validity of the reader */
  bool valid_;
  /** File size */
  size_t size_;
};

}  // namespace keyring_common::data_file

#endif  // !READER_INCLUDED
